`r lifecycle::badge("deprecated")`

The function MARI now owns an argument function `raw` if one wishes to compute the raw version of MARI.

MARIraw(c1, c2, sorted_pairs = NULL)

Details

A function to compute a modified adjusted rand index between two classifications as proposed by Sundqvist (2023), based on a multinomial model. Raw means that the index is not divided by the (maximum - expected) value.

Examples

data(iris)
cl <- cutree(hclust(dist(iris[, -5])), 4)
out <- MARIraw(cl, iris$Species)
#> Warning: `clustComp()` was deprecated in aricode 1.1.0.
#>  Please use `compare_clustering()` instead.
# ->
out <- MARI(cl, iris$Species, raw = TRUE)