A function to compute the NVI between two classifications

NVI(c1, c2)

Arguments

...

Arguments passed on to ARI

c1

a vector containing the labels of the first classification. Must be a vector of characters, integers, a numeric or a factor, but not a list.

c2

a vector containing the labels of the second classification.

Value

a scalar with the normalized variation of information.

See also

Examples

data(iris)
cl <- cutree(hclust(dist(iris[, -5])), 4)
NVI(cl, iris$Species)
#> [1] 0.4792468