A function to compute a modified adjusted rand index between two classifications as proposed by Sundqvist et al. in prep, based on a multinomial model.

MARI(c1, c2)

Arguments

c1

a vector of length n with value between 0 and N1 < n containing the first classification. Must be a vector of integers or characters, a numeric, a factor, but not a list. Avoid character.

c2

a vector of length n with value between 0 and N2 < n containing the second classification. Must be a vector of integers or characters, a numeric or a factor, but not a list. Avoid character.

Value

a scalar with the modified ARI.

See also

Examples

data(iris)
cl <- cutree(hclust(dist(iris[, -5])), 4)
MARI(cl, iris$Species)
#> [1] 0.5894345