A function to compute a modified adjusted rand index between two classifications as proposed by Sundqvist et al. in prep, based on a multinomial model.
MARI(c1, c2)a vector of length n with value between 0 and N1 < n containing the first classification. Must be a vector of integers or characters, a numeric, a factor, but not a list. Avoid character.
a vector of length n with value between 0 and N2 < n containing the second classification. Must be a vector of integers or characters, a numeric or a factor, but not a list. Avoid character.
a scalar with the modified ARI.