`r lifecycle::badge("deprecated")`
The function MARI now owns an argument function `raw` if one wishes to compute the raw version of MARI.
MARIraw(c1, c2, sorted_pairs = NULL)A function to compute a modified adjusted rand index between two classifications as proposed by Sundqvist (2023), based on a multinomial model. Raw means that the index is not divided by the (maximum - expected) value.