A function to compute the NVI between two classifications
NVI(c1, c2)Arguments passed on to ARI
c1a vector containing the labels of the first classification. Must be a vector of characters, integers, a numeric or a factor, but not a list.
c2a vector containing the labels of the second classification.
a scalar with the normalized variation of information.